==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/ConnectorDryrun.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin

import com.pulumi.azurenative.servicelinker.kotlin.outputs.BasicErrorDryrunPrerequisiteResultResponse
import com.pulumi.azurenative.servicelinker.kotlin.outputs.CreateOrUpdateDryrunParametersResponse
import com.pulumi.azurenative.servicelinker.kotlin.outputs.DryrunOperationPreviewResponse
import com.pulumi.azurenative.servicelinker.kotlin.outputs.PermissionsMissingDryrunPrerequisiteResultResponse
import com.pulumi.azurenative.servicelinker.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import com.pulumi.azurenative.servicelinker.kotlin.outputs.CreateOrUpdateDryrunParametersResponse.Companion.toKotlin as createOrUpdateDryrunParametersResponseToKotlin
import com.pulumi.azurenative.servicelinker.kotlin.outputs.DryrunOperationPreviewResponse.Companion.toKotlin as dryrunOperationPreviewResponseToKotlin
import com.pulumi.azurenative.servicelinker.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [ConnectorDryrun].
 */
@PulumiTagMarker
public class ConnectorDryrunResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ConnectorDryrunArgs = ConnectorDryrunArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ConnectorDryrunArgsBuilder.() -> Unit) {
        val builder = ConnectorDryrunArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): ConnectorDryrun {
        val builtJavaResource =
            com.pulumi.azurenative.servicelinker.ConnectorDryrun(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ConnectorDryrun(builtJavaResource)
    }
}

/**
 * a dryrun job resource
 * Azure REST API version: 2022-11-01-preview.
 * ## Example Usage
 * ### ConnectorDryrunCreate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var connectorDryrun = new AzureNative.ServiceLinker.ConnectorDryrun("connectorDryrun", new()
 *     {
 *         DryrunName = "dryrunName",
 *         Location = "westus",
 *         Parameters = new AzureNative.ServiceLinker.Inputs.CreateOrUpdateDryrunParametersArgs
 *         {
 *             ActionName = "createOrUpdate",
 *             AuthInfo = new AzureNative.ServiceLinker.Inputs.SecretAuthInfoArgs
 *             {
 *                 AuthType = "secret",
 *                 Name = "name",
 *                 SecretInfo = new AzureNative.ServiceLinker.Inputs.ValueSecretInfoArgs
 *                 {
 *                     SecretType = "rawValue",
 *                     Value = "secret",
 *                 },
 *             },
 *             TargetService = new AzureNative.ServiceLinker.Inputs.AzureResourceArgs
 *             {
 *                 Id = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-rg/providers/Microsoft.DocumentDb/databaseAccounts/test-acc/mongodbDatabases/test-db",
 *                 Type = "AzureResource",
 *             },
 *         },
 *         ResourceGroupName = "test-rg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/servicelinker/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * pulumi.Run(func(ctx *pulumi.Context) error {
 * _, err := servicelinker.NewConnectorDryrun(ctx, "connectorDryrun", &servicelinker.ConnectorDryrunArgs{
 * DryrunName: pulumi.String("dryrunName"),
 * Location: pulumi.String("westus"),
 * Parameters: interface{}{
 * ActionName: pulumi.String("createOrUpdate"),
 * AuthInfo: servicelinker.SecretAuthInfo{
 * AuthType: "secret",
 * Name: "name",
 * SecretInfo: servicelinker.ValueSecretInfo{
 * SecretType: "rawValue",
 * Value: "secret",
 * },
 * },
 * TargetService: servicelinker.AzureResource{
 * Id: "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-rg/providers/Microsoft.DocumentDb/databaseAccounts/test-acc/mongodbDatabases/test-db",
 * Type: "AzureResource",
 * },
 * },
 * ResourceGroupName: pulumi.String("test-rg"),
 * })
 * if err != nil {
 * return err
 * }
 * return nil
 * })
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.servicelinker.ConnectorDryrun;
 * import com.pulumi.azurenative.servicelinker.ConnectorDryrunArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var connectorDryrun = new ConnectorDryrun("connectorDryrun", ConnectorDryrunArgs.builder()
 *             .dryrunName("dryrunName")
 *             .location("westus")
 *             .parameters(Map.ofEntries(
 *                 Map.entry("actionName", "createOrUpdate"),
 *                 Map.entry("authInfo", Map.ofEntries(
 *                     Map.entry("authType", "secret"),
 *                     Map.entry("name", "name"),
 *                     Map.entry("secretInfo", Map.ofEntries(
 *                         Map.entry("secretType", "rawValue"),
 *                         Map.entry("value", "secret")
 *                     ))
 *                 )),
 *                 Map.entry("targetService", Map.ofEntries(
 *                     Map.entry("id", "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-rg/providers/Microsoft.DocumentDb/databaseAccounts/test-acc/mongodbDatabases/test-db"),
 *                     Map.entry("type", "AzureResource")
 *                 ))
 *             ))
 *             .resourceGroupName("test-rg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:servicelinker:ConnectorDryrun dryrunName /subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/Microsoft.ServiceLinker/locations/{location}/dryruns/{dryrunName}
 * ```
 */
public class ConnectorDryrun internal constructor(
    override val javaResource: com.pulumi.azurenative.servicelinker.ConnectorDryrun,
) : KotlinCustomResource(javaResource, ConnectorDryrunMapper) {
    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * the preview of the operations for creation
     */
    public val operationPreviews: Output<List<DryrunOperationPreviewResponse>>
        get() = javaResource.operationPreviews().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 -> dryrunOperationPreviewResponseToKotlin(args0) })
            })
        })

    /**
     * The parameters of the dryrun
     */
    public val parameters: Output<CreateOrUpdateDryrunParametersResponse>?
        get() = javaResource.parameters().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    createOrUpdateDryrunParametersResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * the result of the dryrun
     */
    public val prerequisiteResults:
        Output<List<Either<BasicErrorDryrunPrerequisiteResultResponse, PermissionsMissingDryrunPrerequisiteResultResponse>>>
        get() = javaResource.prerequisiteResults().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.transform(
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.servicelinker.kotlin.outputs.BasicErrorDryrunPrerequisiteResultResponse.Companion.toKotlin(args0)
                        })
                    },
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.servicelinker.kotlin.outputs.PermissionsMissingDryrunPrerequisiteResultResponse.Companion.toKotlin(args0)
                        })
                    },
                )
            })
        })

    /**
     * The provisioning state.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ConnectorDryrunMapper : ResourceMapper<ConnectorDryrun> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.servicelinker.ConnectorDryrun::class == javaResource::class

    override fun map(javaResource: Resource): ConnectorDryrun = ConnectorDryrun(
        javaResource as
            com.pulumi.azurenative.servicelinker.ConnectorDryrun,
    )
}

/**
 * @see [ConnectorDryrun].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ConnectorDryrun].
 */
public suspend fun connectorDryrun(
    name: String,
    block: suspend ConnectorDryrunResourceBuilder.() -> Unit,
): ConnectorDryrun {
    val builder = ConnectorDryrunResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ConnectorDryrun].
 * @param name The _unique_ name of the resulting resource.
 */
public fun connectorDryrun(name: String): ConnectorDryrun {
    val builder = ConnectorDryrunResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/ConnectorDryrun.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin

import com.pulumi.azurenative.servicelinker.kotlin.outputs.BasicErrorDryrunPrerequisiteResultResponse
import com.pulumi.azurenative.servicelinker.kotlin.outputs.CreateOrUpdateDryrunParametersResponse
import com.pulumi.azurenative.servicelinker.kotlin.outputs.DryrunOperationPreviewResponse
import com.pulumi.azurenative.servicelinker.kotlin.outputs.PermissionsMissingDryrunPrerequisiteResultResponse
import com.pulumi.azurenative.servicelinker.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import com.pulumi.azurenative.servicelinker.kotlin.outputs.CreateOrUpdateDryrunParametersResponse.Companion.toKotlin as createOrUpdateDryrunParametersResponseToKotlin
import com.pulumi.azurenative.servicelinker.kotlin.outputs.DryrunOperationPreviewResponse.Companion.toKotlin as dryrunOperationPreviewResponseToKotlin
import com.pulumi.azurenative.servicelinker.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [ConnectorDryrun].
 */
@PulumiTagMarker
public class ConnectorDryrunResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ConnectorDryrunArgs = ConnectorDryrunArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ConnectorDryrunArgsBuilder.() -> Unit) {
        val builder = ConnectorDryrunArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): ConnectorDryrun {
        val builtJavaResource =
            com.pulumi.azurenative.servicelinker.ConnectorDryrun(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ConnectorDryrun(builtJavaResource)
    }
}

/**
 * a dryrun job resource
 * Azure REST API version: 2022-11-01-preview.
 * Other available API versions: 2023-04-01-preview.
 * ## Example Usage
 * ### ConnectorDryrunCreate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var connectorDryrun = new AzureNative.ServiceLinker.ConnectorDryrun("connectorDryrun", new()
 *     {
 *         DryrunName = "dryrunName",
 *         Location = "westus",
 *         Parameters = new AzureNative.ServiceLinker.Inputs.CreateOrUpdateDryrunParametersArgs
 *         {
 *             ActionName = "createOrUpdate",
 *             AuthInfo = new AzureNative.ServiceLinker.Inputs.SecretAuthInfoArgs
 *             {
 *                 AuthType = "secret",
 *                 Name = "name",
 *                 SecretInfo = new AzureNative.ServiceLinker.Inputs.ValueSecretInfoArgs
 *                 {
 *                     SecretType = "rawValue",
 *                     Value = "secret",
 *                 },
 *             },
 *             TargetService = new AzureNative.ServiceLinker.Inputs.AzureResourceArgs
 *             {
 *                 Id = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-rg/providers/Microsoft.DocumentDb/databaseAccounts/test-acc/mongodbDatabases/test-db",
 *                 Type = "AzureResource",
 *             },
 *         },
 *         ResourceGroupName = "test-rg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/servicelinker/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := servicelinker.NewConnectorDryrun(ctx, "connectorDryrun", &servicelinker.ConnectorDryrunArgs{
 * 			DryrunName: pulumi.String("dryrunName"),
 * 			Location:   pulumi.String("westus"),
 * 			Parameters: &servicelinker.CreateOrUpdateDryrunParametersArgs{
 * 				ActionName: pulumi.String("createOrUpdate"),
 * 				AuthInfo: servicelinker.SecretAuthInfo{
 * 					AuthType: "secret",
 * 					Name:     "name",
 * 					SecretInfo: servicelinker.ValueSecretInfo{
 * 						SecretType: "rawValue",
 * 						Value:      "secret",
 * 					},
 * 				},
 * 				TargetService: servicelinker.AzureResource{
 * 					Id:   "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-rg/providers/Microsoft.DocumentDb/databaseAccounts/test-acc/mongodbDatabases/test-db",
 * 					Type: "AzureResource",
 * 				},
 * 			},
 * 			ResourceGroupName: pulumi.String("test-rg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.servicelinker.ConnectorDryrun;
 * import com.pulumi.azurenative.servicelinker.ConnectorDryrunArgs;
 * import com.pulumi.azurenative.servicelinker.inputs.CreateOrUpdateDryrunParametersArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var connectorDryrun = new ConnectorDryrun("connectorDryrun", ConnectorDryrunArgs.builder()
 *             .dryrunName("dryrunName")
 *             .location("westus")
 *             .parameters(CreateOrUpdateDryrunParametersArgs.builder()
 *                 .actionName("createOrUpdate")
 *                 .authInfo(AccessKeyInfoBaseArgs.builder()
 *                     .authType("secret")
 *                     .name("name")
 *                     .secretInfo(%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
 *                     .build())
 *                 .targetService(AzureResourceArgs.builder()
 *                     .id("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-rg/providers/Microsoft.DocumentDb/databaseAccounts/test-acc/mongodbDatabases/test-db")
 *                     .type("AzureResource")
 *                     .build())
 *                 .build())
 *             .resourceGroupName("test-rg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:servicelinker:ConnectorDryrun dryrunName /subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/Microsoft.ServiceLinker/locations/{location}/dryruns/{dryrunName}
 * ```
 */
public class ConnectorDryrun internal constructor(
    override val javaResource: com.pulumi.azurenative.servicelinker.ConnectorDryrun,
) : KotlinCustomResource(javaResource, ConnectorDryrunMapper) {
    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * the preview of the operations for creation
     */
    public val operationPreviews: Output<List<DryrunOperationPreviewResponse>>
        get() = javaResource.operationPreviews().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 -> dryrunOperationPreviewResponseToKotlin(args0) })
            })
        })

    /**
     * The parameters of the dryrun
     */
    public val parameters: Output<CreateOrUpdateDryrunParametersResponse>?
        get() = javaResource.parameters().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    createOrUpdateDryrunParametersResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * the result of the dryrun
     */
    public val prerequisiteResults:
        Output<List<Either<BasicErrorDryrunPrerequisiteResultResponse, PermissionsMissingDryrunPrerequisiteResultResponse>>>
        get() = javaResource.prerequisiteResults().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.transform(
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.servicelinker.kotlin.outputs.BasicErrorDryrunPrerequisiteResultResponse.Companion.toKotlin(args0)
                        })
                    },
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.servicelinker.kotlin.outputs.PermissionsMissingDryrunPrerequisiteResultResponse.Companion.toKotlin(args0)
                        })
                    },
                )
            })
        })

    /**
     * The provisioning state.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ConnectorDryrunMapper : ResourceMapper<ConnectorDryrun> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.servicelinker.ConnectorDryrun::class == javaResource::class

    override fun map(javaResource: Resource): ConnectorDryrun = ConnectorDryrun(
        javaResource as
            com.pulumi.azurenative.servicelinker.ConnectorDryrun,
    )
}

/**
 * @see [ConnectorDryrun].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ConnectorDryrun].
 */
public suspend fun connectorDryrun(
    name: String,
    block: suspend ConnectorDryrunResourceBuilder.() -> Unit,
): ConnectorDryrun {
    val builder = ConnectorDryrunResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ConnectorDryrun].
 * @param name The _unique_ name of the resulting resource.
 */
public fun connectorDryrun(name: String): ConnectorDryrun {
    val builder = ConnectorDryrunResourceBuilder()
    builder.name(name)
    return builder.build()
}
